@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.08';
+our $VERSION = '0.0801';
 
 use Moo;
 use strictures 2;
@@ -67,9 +67,7 @@ sub analyze {
     my $negative = Lingua::EN::Opinion::Negative->new();
 
     for my $sentence ( @sentences ) {
-        $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
-
-        my @words = split /\s+/, $sentence;
+        my @words = _tokenize($sentence);
 
         my $score = 0;
 
@@ -120,9 +118,7 @@ sub nrc_sentiment {
     my $emotion = Lingua::EN::Opinion::Emotion->new();
 
     for my $sentence ( @sentences ) {
-        $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
-
-        my @words = split /\s+/, $sentence;
+        my @words = _tokenize($sentence);
 
         my $score;
 
@@ -173,8 +169,7 @@ sub nrc_get_word {
 sub get_sentence {
     my ( $self, $sentence ) = @_;
 
-    $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
-    my @words = split /\s+/, $sentence;
+    my @words = _tokenize($sentence);
 
     my %score;
     $score{$_} = $self->get_word($_) for @words;
@@ -186,8 +181,7 @@ sub get_sentence {
 sub nrc_get_sentence {
     my ( $self, $sentence ) = @_;
 
-    $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
-    my @words = split /\s+/, $sentence;
+    my @words = _tokenize($sentence);
 
     my %score;
     $score{$_} = $self->nrc_get_word($_) for @words;
@@ -195,6 +189,13 @@ sub nrc_get_sentence {
     return \%score;
 }
 
+sub _tokenize {
+    my ($sentence) = @_;
+    $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
+    my @words = split /\s+/, $sentence;
+    return @words;
+}
+
 1;
 
 __END__
@@ -209,7 +210,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -218,11 +219,13 @@ version 0.08
   $opinion->analyze();
   my $score = $opinion->averaged_score(5);
   my $sentiment = $opinion->get_word('foo');
+  $sentiment = $opinion->get_sentence('Mary had a little lamb.');
   # OR
   $opinion = Lingua::EN::Opinion->new( text => 'Mary had a little lamb...' );
   $opinion->nrc_sentiment();
   # And now do something cool with $opinion->nrc_scores...
   $sentiment = $opinion->nrc_get_word('foo');
+  $sentiment = $opinion->nrc_get_sentence('Mary had a little lamb.');
 
 =head1 DESCRIPTION
 
